@@ -145,6 +145,7 @@ doe <- function(factors, int = "", trials = NA, seed = NA) {
 #' @param eff If TRUE print efficiency output
 #' @param part If TRUE print partial factorial
 #' @param full If TRUE print full factorial
+#' @param est If TRUE print number of effects that will be estimable using the partial factorial design
 #' @param dec Number of decimals to show
 #' @param ... further arguments passed to or from other methods.
 #'
@@ -156,7 +157,7 @@ doe <- function(factors, int = "", trials = NA, seed = NA) {
 #'   summary()
 #'
 #' @export
-summary.doe <- function(object, eff = TRUE, part = TRUE, full = TRUE, dec = 3, ...) {
+summary.doe <- function(object, eff = TRUE, part = TRUE, full = TRUE, est = TRUE, dec = 3, ...) {
   if (!is.list(object)) return(object)
 
   cat("Experimental design\n")
@@ -178,6 +179,7 @@ summary.doe <- function(object, eff = TRUE, part = TRUE, full = TRUE, dec = 3, .
       print(row.names = FALSE)
 
     cat("\nPartial factorial design correlations:\n")
+    cat("** Note: Variables are assumed to be ordinal **\n")
     round(object$cor_mat, ifelse(object$detcm == 1, 0, dec)) %>%
       print(row.names = FALSE)
   }
@@ -187,8 +189,50 @@ summary.doe <- function(object, eff = TRUE, part = TRUE, full = TRUE, dec = 3, .
     print(object$part, row.names = FALSE)
   }
 
+  if (est) {
+    cat("\nEstimable effects from partial factorial design:\n\n")
+    cat(paste(" ", estimable(object), collapse = "\n"), "\n")
+  }
+
   if (full) {
     cat("\nFull factorial design:\n")
     print(object$full, row.names = FALSE)
   }
 }
+
+#' Determine coefficients that can be estimated based on a partial factorial design
+#'
+#' @description A function to determine which coefficients can be estimated based on a partial factorial design. Adapted from a function written by Blakeley McShane at https://github.com/fzettelmeyer/mktg482/blob/master/R/expdesign.R
+#'
+#' @param design An experimental design generated by the doe function that includes a partial and full factorial design
+#' @examples
+#' design <- doe(c("price; $10; $13; $16", "food; popcorn; gourmet; no food"), trials = 6)
+#' estimable(design)
+#
+#' @export
+estimable <- function(design) {
+
+  if (!inherits(design, "doe")) {
+    return(add_class("The estimable function requires input of type 'doe'. Please use the ratiant.design::doe function to generate an appropriate design", "doe"))
+  }
+
+  full <- design$full
+  fm <- as.formula(paste("trial ~ ", paste(colnames(full)[-1], collapse = "*")))
+  mod1 <- lm(fm, data = full)
+  coef1 <- coef(mod1)
+
+  mod2 <- lm(fm, data = design$part)
+  coef2 <- coef(mod2)
+  coef2 <- coef2[!is.na(coef2)]
+
+  ## format levels
+  hasLevs <- sapply(full[, -1, drop = FALSE], function(x) is.factor(x) || is.logical(x) || is.character(x))
+  if (sum(hasLevs) > 0) {
+    for (i in names(hasLevs[hasLevs])) {
+      names(coef2) %<>% gsub(paste0("^", i), paste0(i, "|"), .) %>%
+        gsub(paste0(":", i), paste0(":", i, "|"), .)
+    }
+  }
+
+  names(coef2[-1])
+}
